@@ -3,27 +3,32 @@ use strict;
 use warnings;
 use Data::Printer::Common;
 
+# the theme name
 sub name {
     my ($self) = @_;
     return $self->{name};
 }
 
+# true if the theme has at least one color override
 sub customized {
     my ($self) = @_;
     return exists $self->{is_custom} ? 1 : 0;
 }
 
+# displays the color as-is
 sub color_for {
     my ($self, $color_type) = @_;
     return $self->{colors}{$color_type} || '';
 }
 
+# prints the SGR (terminal) color modifier
 sub sgr_color_for {
     my ($self, $color_type) = @_;
     return unless exists $self->{sgr_colors}{$color_type};
     return $self->{sgr_colors}{$color_type} || ''
 }
 
+# prints the SGR (terminal) color reset modifier
 sub color_reset { return "\e[0m" }
 
 sub new {
@@ -258,16 +263,25 @@ Data::Printer comes with several themes for you to choose from:
 
 =item * L<Material|Data::Printer::Theme::Material> I<(the default)>
 
+=for html <a href="https://metacpan.org/pod/Data::Printer::Theme::Material"><img style="height:50%" src="https://raw.githubusercontent.com/garu/Data-Printer/master/examples/theme-material.png" alt="Material Theme" /></a>
+
 =item * L<Monokai|Data::Printer::Theme::Monokai>
 
+=for html <a href="https://metacpan.org/pod/Data::Printer::Theme::Monokai"><img style="height:50%" src="https://raw.githubusercontent.com/garu/Data-Printer/master/examples/theme-monokai.png" alt="Monokai Theme" /></a>
+
 =item * L<Solarized|Data::Printer::Theme::Solarized>
 
+=for html <a href="https://metacpan.org/pod/Data::Printer::Theme::Solarized"><img style="height:50%" src="https://raw.githubusercontent.com/garu/Data-Printer/master/examples/theme-solarized.png" alt="Solarized Theme" /></a>
+
 =item * L<Classic|Data::Printer::Theme::Classic> I<(original pre-1.0 colors)>
 
+=for html <a href="https://metacpan.org/pod/Data::Printer::Theme::Classic"><img style="height:50%" src="https://raw.githubusercontent.com/garu/Data-Printer/master/examples/theme-classic.png" alt="Classic Theme" /></a>
+
 =back
 
 Run C<< examples/try_me.pl >> to see them in action on your own terminal!
 
+
 =head1 CREATING YOUR THEMES
 
 A theme is a module in the C<Data::Printer::Theme> namespace. It doesn't have
@@ -310,33 +324,6 @@ B<NOTE:> There may not be a real 1:1 conversion between RGB and
 terminal colors. In those cases we use approximation to achieve the
 closest option.
 
-=head1 PUBLIC INTERFACE
-
-This module is not meant for public use. The following documentation is
-mostly for developers of Data::Printer itself.
-
-=over 4
-
-=item * C<< new( %params ) >> - creates a new theme object
-
-    my $theme = Data::Printer::Theme->new(
-        name            => 'Material',
-        color_level     => 1,
-        color_overrides => { ... },
-    );
-
-=item * C<< name >> - displays the theme name.
-
-=item * C<< customized >> - true if theme has at least one color override.
-
-=item * C<< color_for( $label ) >> - displays the color as-is.
-
-=item * C<< sgr_color_for( $label ) >> - prints the SGR (terminal) color modifier.
-
-=item * C<< color_reset >> - prints the SGR (terminal) color reset modifier.
-
-=back
-
 =head1 SEE ALSO
 
 L<Data::Printer>
